==> pegasus-merchandise-api-1.3.11-sources.jar: com/thebeastshop/pegasus/merchandise/vo/OpProdDynmDetailsVO.java <==
/*
 * Copyright (C), 上海布鲁爱电子商务有限公司
 */
package com.thebeastshop.pegasus.merchandise.vo;

import java.io.Serializable;
import java.util.List;

/**
 * @author Roy.Chen
 * @version $Id: OpSkuDynmContentVO.java, v 0.1 2015-08-05 10:56
 */
public class OpProdDynmDetailsVO implements Serializable {
	/**
	 * id
	 */
	private Long id;
    /**
     * 商品prodCode
     */
    private String prodCode;

    /**
     * 商品prodId
     */
    private Long prodId;
    
    /**
     * 动态内容栏目id
     */
    private Integer dynmcontId;
    
    /**
     * 动态内容类型1-图片 2-文字 3表格
     */
    private Integer dynmcontType;
    
    /**
     * 动态内容标题
     */
    private String dynmcontTitle;
    
    /**
     * 动态内容
     */
    private String dynmcontContent;
    
    /**
     * 动态内容排序
     */
    private Integer sort;
    
    /**
	 * 动态栏目中文名称
	 */
	private String titleCn;
	
	/**
	 * 动态栏目中文名称
	 */
	private String titleEn;
	
	 /**
     * 栏目是否展开0-展开 1-不展开
     */
    private Integer isOpen;
    
    /**
     * 栏目demo
     */
    private String demo;
    
    /**
     * 栏目排序
     */
    private Integer cloumnSort;
    
    /**
     * 栏目内容详情
     */
    private List<OpProdDynmDetailsContentVO> detailsContentVOList;
    
    /**
     * 动态内容表格详情LIST
     */
    private List<OpProdDynmDetailsVO> dynmExcelList;

    public List<OpProdDynmDetailsVO> getDynmExcelList() {
		return dynmExcelList;
	}

	public void setDynmExcelList(List<OpProdDynmDetailsVO> dynmExcelList) {
		this.dynmExcelList = dynmExcelList;
	}

	public Long getId() {
		return id;
	}

	public void setId(Long id) {
		this.id = id;
	}

	public Integer getDynmcontType() {
		return dynmcontType;
	}

	public void setDynmcontType(Integer dynmcontType) {
		this.dynmcontType = dynmcontType;
	}

	public String getDynmcontTitle() {
		return dynmcontTitle;
	}

	public void setDynmcontTitle(String dynmcontTitle) {
		this.dynmcontTitle = dynmcontTitle;
	}

	public String getDynmcontContent() {
		return dynmcontContent;
	}

	public void setDynmcontContent(String dynmcontContent) {
		this.dynmcontContent = dynmcontContent;
	}

	public Integer getSort() {
		return sort;
	}

	public void setSort(Integer sort) {
		this.sort = sort;
	}

	public Integer getDynmcontId() {
		return dynmcontId;
	}

	public void setDynmcontId(Integer dynmcontId) {
		this.dynmcontId = dynmcontId;
	}

	public List<OpProdDynmDetailsContentVO> getDetailsContentVOList() {
		return detailsContentVOList;
	}

	public void setDetailsContentVOList(List<OpProdDynmDetailsContentVO> detailsContentVOList) {
		this.detailsContentVOList = detailsContentVOList;
	}

	public String getProdCode() {
		return prodCode;
	}

	public void setProdCode(String prodCode) {
		this.prodCode = prodCode;
	}

	public Long getProdId() {
		return prodId;
	}

	public void setProdId(Long prodId) {
		this.prodId = prodId;
	}

	public String getTitleCn() {
		return titleCn;
	}

	public void setTitleCn(String titleCn) {
		this.titleCn = titleCn;
	}

	public Integer getIsOpen() {
		return isOpen;
	}

	public void setIsOpen(Integer isOpen) {
		this.isOpen = isOpen;
	}

	public String getDemo() {
		return demo;
	}

	public void setDemo(String demo) {
		this.demo = demo;
	}

	public Integer getCloumnSort() {
		return cloumnSort;
	}

	public void setCloumnSort(Integer cloumnSort) {
		this.cloumnSort = cloumnSort;
	}

	public String getTitleEn() {
		return titleEn;
	}

	public void setTitleEn(String titleEn) {
		this.titleEn = titleEn;
	}
	
}

==> pegasus-merchandise-api-2.2.30-sources.jar: com/thebeastshop/pegasus/merchandise/vo/OpProdDynmDetailsVO.java <==
/*
 * Copyright (C), 上海布鲁爱电子商务有限公司
 */
package com.thebeastshop.pegasus.merchandise.vo;

import java.io.Serializable;
import java.util.List;

/**
 * @author Roy.Chen
 * @version $Id: OpSkuDynmContentVO.java, v 0.1 2015-08-05 10:56
 */
public class OpProdDynmDetailsVO implements Serializable {
	/**
	 * id
	 */
	private Long id;
    /**
     * 商品prodCode
     */
    private String prodCode;

    /**
     * 商品prodId
     */
    private Long prodId;
    
    /**
     * 动态内容栏目id
     */
    private Integer dynmcontId;
    
    /**
     * 动态内容类型1-图片 2-文字 3表格
     */
    private Integer dynmcontType;
    
    /**
     * 动态内容标题
     */
    private String dynmcontTitle;
    
    /**
     * 动态内容
     */
    private String dynmcontContent;
    
    /**
     * 动态内容排序
     */
    private Integer sort;
    
    /**
	 * 动态栏目中文名称
	 */
	private String titleCn;
	
	/**
	 * 动态栏目中文名称
	 */
	private String titleEn;
	
	 /**
     * 栏目是否展开0-展开 1-不展开
     */
    private Integer isOpen;
    
    /**
     * 栏目demo
     */
    private String demo;
    
    /**
     * 栏目排序
     */
    private Integer columnSort;
    
    /**
     * 栏目内容详情
     */
    private List<OpProdDynmDetailsContentVO> detailsContentVOList;
    
    /**
     * 动态内容表格详情LIST
     */
    private List<OpProdDynmDetailsVO> dynmExcelList;

    public List<OpProdDynmDetailsVO> getDynmExcelList() {
		return dynmExcelList;
	}

	public void setDynmExcelList(List<OpProdDynmDetailsVO> dynmExcelList) {
		this.dynmExcelList = dynmExcelList;
	}

	public Long getId() {
		return id;
	}

	public void setId(Long id) {
		this.id = id;
	}

	public Integer getDynmcontType() {
		return dynmcontType;
	}

	public void setDynmcontType(Integer dynmcontType) {
		this.dynmcontType = dynmcontType;
	}

	public String getDynmcontTitle() {
		return dynmcontTitle;
	}

	public void setDynmcontTitle(String dynmcontTitle) {
		this.dynmcontTitle = dynmcontTitle;
	}

	public String getDynmcontContent() {
		return dynmcontContent;
	}

	public void setDynmcontContent(String dynmcontContent) {
		this.dynmcontContent = dynmcontContent;
	}

	public Integer getSort() {
		return sort;
	}

	public void setSort(Integer sort) {
		this.sort = sort;
	}

	public Integer getDynmcontId() {
		return dynmcontId;
	}

	public void setDynmcontId(Integer dynmcontId) {
		this.dynmcontId = dynmcontId;
	}

	public List<OpProdDynmDetailsContentVO> getDetailsContentVOList() {
		return detailsContentVOList;
	}

	public void setDetailsContentVOList(List<OpProdDynmDetailsContentVO> detailsContentVOList) {
		this.detailsContentVOList = detailsContentVOList;
	}

	public String getProdCode() {
		return prodCode;
	}

	public void setProdCode(String prodCode) {
		this.prodCode = prodCode;
	}

	public Long getProdId() {
		return prodId;
	}

	public void setProdId(Long prodId) {
		this.prodId = prodId;
	}

	public String getTitleCn() {
		return titleCn;
	}

	public void setTitleCn(String titleCn) {
		this.titleCn = titleCn;
	}

	public Integer getIsOpen() {
		return isOpen;
	}

	public void setIsOpen(Integer isOpen) {
		this.isOpen = isOpen;
	}

	public String getDemo() {
		return demo;
	}

	public void setDemo(String demo) {
		this.demo = demo;
	}

    public Integer getColumnSort() {
        return columnSort;
    }

    public void setColumnSort(Integer columnSort) {
        this.columnSort = columnSort;
    }

    public String getTitleEn() {
		return titleEn;
	}

	public void setTitleEn(String titleEn) {
		this.titleEn = titleEn;
	}
	
}
